@@ -1,12 +1,13 @@
-# $Id: Dependency.pm,v 1.7 2007/12/03 17:46:47 drhyde Exp $
-#!perl -w
 package CPAN::FindDependencies::Dependency;
 
+require CPAN::FindDependencies;
+
 use strict;
+use warnings;
 
 use vars qw($VERSION);
 
-$VERSION = '2.0';
+$VERSION = '2.99_01';
 
 =head1 NAME
 
@@ -17,7 +18,7 @@ CPAN::FindDependencies::Dependency - object representing a module dependency
     my @dependencies = CPAN::FindDependencies::finddeps("CPAN");
     foreach my $dep (@dependencies) {
         print ' ' x $dep->depth();
-        print $dep->name().' ('.$dep->distribution().")\n";
+        print $dep->name().' (dist: '.$dep->distribution().', mod ver: '.$dep->version().")\n";
     }
 
 =head1 METHODS
@@ -48,7 +49,17 @@ The name of the distribution containing the module
 =cut
 
 sub distribution {
-    $_[0]->{p}->package($_[0]->name())->distribution()->prefix();
+    $_[0]->{distribution}->prefix();
+}
+
+=head2 version
+
+The minimum required version (if specified) of the module
+
+=cut
+
+sub version {
+  $_[0]->{version}
 }
 
 =head2 depth
@@ -76,12 +87,12 @@ None known
 
 I welcome feedback about my code, including constructive criticism
 and bug reports.  The best bug reports include files that I can add
-to the test suite, which fail with the current code in CVS and will
-pass once I've fixed the bug
+to the test suite, which fail with the current code in my git repo and
+will pass once I've fixed the bug
 
-=head1 CVS
+=head1 SOURCE CODE REPOSITORY
 
-L<http://drhyde.cvs.sourceforge.net/drhyde/perlmodules/CPAN-FindDependencies/>
+L<git://github.com/DrHyde/perl-modules-CPAN-FindDependencies.git>
 
 =head1 SEE ALSO
 
@@ -89,14 +100,17 @@ L<CPAN::FindDepdendencies>
 
 L<CPAN>
 
-L<http://cpandeps.cantrell.org.uk/>
+L<http://deps.cpantesters.org/>
 
 =head1 AUTHOR, LICENCE and COPYRIGHT
 
 Copyright 2007 David Cantrell E<lt>F<david@cantrell.org.uk>E<gt>
 
-This module is free-as-in-speech software, and may be used,
-distributed, and modified under the same terms as Perl itself.
+This software is free-as-in-speech software, and may be used,
+distributed, and modified under the terms of either the GNU
+General Public Licence version 2 or the Artistic Licence. It's
+up to you which one you use. The full text of the licences can
+be found in the files GPL2.txt and ARTISTIC.txt, respectively.
 
 =head1 CONSPIRACY
 
